%define build_plf 0
%if "%{?distro_section}" == "tainted"
%define build_plf 1
%endif
%define minver %(echo %version | cut -d. -f1,2)

Name:           mpd
Version:        0.24.4
Release:        %mkrel 2

Summary:        MPD, the Music Player Daemon
License:        GPLv2+
Group:          Sound/Players
Url:            https://www.musicpd.org/
Source0:        https://www.musicpd.org/download/mpd/%{minver}/%{name}-%{version}.tar.xz
Source1:        %{name}.conf
Source2:        %{name}.logrotate
Source3:        README.urpmi.2

BuildRequires: meson
BuildRequires: ninja
BuildRequires: cmake(nlohmann_json)
BuildRequires: pkgconfig(adplug)
BuildRequires: pkgconfig(alsa) >= 0.9.0
BuildRequires: pkgconfig(ao)
BuildRequires: pkgconfig(audiofile) >= 0.1.7
BuildRequires: pkgconfig(avahi-client)
BuildRequires: pkgconfig(avahi-glib)
BuildRequires: boost-devel
BuildRequires: pkgconfig(flac) >= 1.1
BuildRequires: pkgconfig(fluidsynth) >= 1.1
BuildRequires: pkgconfig(fmt) >= 9
BuildRequires: pkgconfig(glib-2.0) >= 2.16
BuildRequires: pkgconfig(gthread-2.0)
BuildRequires: pkgconfig(icu-uc)
BuildRequires: pkgconfig(id3tag)
BuildRequires: pkgconfig(jack) >= 0.100
BuildRequires: pkgconfig(libavcodec) >= 52.20
BuildRequires: pkgconfig(libavformat) >= 52.31
BuildRequires: pkgconfig(libavutil) >= 49.15
BuildRequires: pkgconfig(libcurl)
BuildRequires: pkgconfig(libchromaprint)
BuildRequires: pkgconfig(libffado)
BuildRequires: pkgconfig(libgme)
BuildRequires: pkgconfig(libmms) >= 0.4
BuildRequires: pkgconfig(libmodplug)
BuildRequires: pkgconfig(libmpg123)
BuildRequires: pkgconfig(libmpdclient)
BuildRequires: pkgconfig(libnfs)
BuildRequires: pkgconfig(libopenmpt)
BuildRequires: pkgconfig(libpcre2-8)
BuildRequires: pkgconfig(libpipewire-0.3)
BuildRequires: pkgconfig(libpulse)
BuildRequires: pkgconfig(libsidplay2)
BuildRequires: pkgconfig(libsidplayfp)
BuildRequires: pkgconfig(libsidutils)
BuildRequires: pkgconfig(libupnp)
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(mad)
BuildRequires: pkgconfig(libmikmod)
BuildRequires: pkgconfig(ogg)
BuildRequires: pkgconfig(openal)
BuildRequires: pkgconfig(samplerate) >= 0.0.15
BuildRequires: pkgconfig(shout)
BuildRequires: pkgconfig(smbclient)
BuildRequires: pkgconfig(sndfile)
BuildRequires: pkgconfig(sndio)
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(soxr)
BuildRequires: pkgconfig(liburing)
BuildRequires: pkgconfig(vorbis)
BuildRequires: pkgconfig(vorbisenc)
BuildRequires: pkgconfig(vorbisfile)
BuildRequires: pkgconfig(wavpack)
BuildRequires: pkgconfig(wildmidi)
BuildRequires: pkgconfig(yajl) >= 2.0
BuildRequires: pkgconfig(zziplib) >= 0.13
BuildRequires: lame-devel
BuildRequires: musepack-devel
%if %build_plf
BuildRequires: pkgconfig(faad2)
%endif
BuildRequires: pkgconfig(libcdio_paranoia)
BuildRequires: pkgconfig(libiso9660)
BuildRequires: python3dist(sphinx)

Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1

%description
Music Player Daemon (MPD) allows remote access for playing music (MP3, Ogg
Vorbis, FLAC, Mod, and wave files) and managing playlists. MPD is designed
for integrating a computer into a stereo system that provides control for music
playback over a local network. It is also makes a great desktop music player,
especially if you're a console junkie, like frontend options, or restart X
often.
%if %build_plf
This package is in the 'tainted' section because it is built with AAC support
of libfaad2.
%endif

%prep
%autosetup -p1

%build
%meson \
%if %build_plf
  -Dfaad=enabled \
%else
  -Dfaad=disabled \
%endif
  -Dmpcdec=enabled \
  -Dshine=disabled \
  -Dtremor=disabled

%meson_build

%install
%meson_install

mkdir -p %{buildroot}/var/lib/mpd
touch %{buildroot}%{_localstatedir}/lib/mpd/mpd.db
touch %{buildroot}%{_localstatedir}/lib/mpd/mpdstate
mkdir -p %{buildroot}/var/log/mpd
touch %{buildroot}/var/log/mpd/mpd.log
touch %{buildroot}/var/log/mpd/mpd.error
mkdir -p %{buildroot}%{_localstatedir}/lib/mpd/playlists
mkdir -p %{buildroot}%{_localstatedir}/lib/mpd/music

install -D %{SOURCE1} %{buildroot}/etc/mpd.conf
install -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install %{SOURCE3} doc/README.urpmi
rm -rf %{buildroot}%{_docdir}/mpd

mkdir -p %{buildroot}%{_tmpfilesdir}
cat <<EOF > %{buildroot}%{_tmpfilesdir}/%{name}.conf
d /run/mpd 0755 mpd audio
EOF

install -d -m 0755 %{buildroot}%{_rundir}/%{name}

%pre
%_pre_useradd %name %{_localstatedir}/lib/%{name} /bin/false
usermod -g audio %{name}

%post
%_tmpfilescreate %{name}
if [ $1 -eq 1 ]
then
%create_ghostfile %{_localstatedir}/lib/mpd/mpd.db mpd audio 644
%create_ghostfile %{_localstatedir}/lib/mpd/mpdstate mpd audio 644
%create_ghostfile /var/log/mpd/mpd.log mpd audio 644
%create_ghostfile /var/log/mpd/mpd.error mpd audio 644
fi
#echo If you want to run mpd as a service, please read
#echo /usr/share/doc/mpd-%%{version}/README.MDK
%_post_service %{name}

%preun
%_preun_service %{name}

%postun
%_postun_userdel %{name}

%files
%doc README.md AUTHORS NEWS doc/mpdconf.example doc/*.urpmi
%{_bindir}/%{name}
%{_iconsdir}/hicolor/scalable/apps/mpd.svg
%{_mandir}/man1/mpd.1*
%{_mandir}/man5/mpd.conf.5*
%{_unitdir}/mpd.service
%{_unitdir}/mpd.socket
%{_userunitdir}/mpd.service
%{_userunitdir}/mpd.socket
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%attr(-,mpd,root) %config(noreplace) %{_sysconfdir}/%{name}.conf
%{_tmpfilesdir}/%{name}.conf
%defattr(644,mpd,audio)
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd/music
%attr(755,mpd,audio) %dir %{_localstatedir}/lib/mpd/playlists
%ghost %{_localstatedir}/lib/mpd/mpd.db
%ghost %{_localstatedir}/lib/mpd/mpdstate
%attr(755,mpd,audio) %dir /var/log/mpd
%ghost /var/log/mpd/mpd.log
%ghost /var/log/mpd/mpd.error
%dir %ghost %attr(0755,mpd,audio) %{_rundir}/mpd
%ghost %attr(0660, -, -) %{_rundir}/mpd/mpd.pid


%changelog
* Sat Jul 19 2025 daviddavid <daviddavid> 0.24.4-2.mga10
+ Revision: 2257275
- rebuild for new flac 1.5.0

* Thu Jul 17 2025 daviddavid <daviddavid> 0.24.4-1.mga10
+ Revision: 2256817
- new version: 0.24.4

* Thu Jul 03 2025 umeabot <umeabot> 0.23.17-3.mga10.tainted
+ Revision: 2244451
- Mageia 10 Mass Rebuild

* Sat Jun 14 2025 daviddavid <daviddavid> 0.23.17-2.mga10
+ Revision: 2191064
- rebuild for new adplug 2.4

* Thu Jan 30 2025 daviddavid <daviddavid> 0.23.17-1.mga10
+ Revision: 2143561
- new version: 0.23.17
- rebuild for new libcdio 2.2.0

* Sun Jan 12 2025 wally <wally> 0.23.16-2.mga10.tainted
+ Revision: 2138390
- rebuild for icu 76.1

* Sun Dec 08 2024 daviddavid <daviddavid> 0.23.16-1.mga10
+ Revision: 2122723
- new version: 0.23.16
- remove merged upstream patch

* Sun Dec 08 2024 daviddavid <daviddavid> 0.23.15-4.mga10
+ Revision: 2122632
- rebuild for new ffmpeg 7.1

* Wed Oct 02 2024 daviddavid <daviddavid> 0.23.15-3.mga10
+ Revision: 2102510
- backport upstream patch to fix build with fmt 11.x
- rebuild for new fmt 11.0.2

* Tue Jun 11 2024 daviddavid <daviddavid> 0.23.15-2.mga10.tainted
+ Revision: 2072700
- rebuild for new libsidplayfp 2.8.0

* Sun Apr 14 2024 daviddavid <daviddavid> 0.23.15-1.mga10.tainted
+ Revision: 2057401
- new version: 0.23.15

* Sun Apr 14 2024 wally <wally> 0.23.11-6.mga10.tainted
+ Revision: 2057365
- fix build with gcc14
+ daviddavid <daviddavid>
- drop unwanted initscript

* Tue Oct 03 2023 daviddavid <daviddavid> 0.23.11-5.mga10.tainted
+ Revision: 1993551
- dependency libsoup2.4 no more used

* Mon Jun 05 2023 daviddavid <daviddavid> 0.23.11-4.mga9
+ Revision: 1961042
- enable openmpt support

* Thu Mar 30 2023 daviddavid <daviddavid> 0.23.11-3.mga9
+ Revision: 1950861
- time to enable musepack SV8 support

* Sat Jan 07 2023 squidf <squidf> 0.23.11-2.mga9.tainted
+ Revision: 1931147
- Mass rebuild for icu 72.1

* Tue Jan 03 2023 daviddavid <daviddavid> 0.23.11-1.mga9
+ Revision: 1929525
- new version: 0.23.11
- add gentoo patch to fix build with boost 1.81

* Sun Nov 20 2022 wally <wally> 0.23.10-2.mga9.tainted
+ Revision: 1909277
- rebuild for flac 1.4.2

* Tue Nov 01 2022 papoteur <papoteur> 0.23.10-1.mga9
+ Revision: 1901111
- new 0.23.10
- Rebuild for libfmt 9.1.0

* Sat Jun 18 2022 squidf <squidf> 0.23.7-2.mga9
+ Revision: 1864879
- rebuild for icu 71.1

* Mon Jun 13 2022 papoteur <papoteur> 0.23.7-1.mga9.tainted
+ Revision: 1864356
- new 0.23.7

* Mon Mar 21 2022 danf <danf> 0.23.6-1.mga9.tainted
+ Revision: 1815991
- Update to ver. 0.23.6
- Switch to HTTPS URLs
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Mon Mar 07 2022 luigiwalser <luigiwalser> 0.21.26-6.mga9.tainted
+ Revision: 1789522
- rebuild for libnfs

* Thu Aug 05 2021 luigiwalser <luigiwalser> 0.21.26-5.mga9.tainted
+ Revision: 1739417
- rebuild for fluidsynth

* Tue Aug 03 2021 luigiwalser <luigiwalser> 0.21.26-4.mga9
+ Revision: 1738953
- rebuild for icu

* Tue May 25 2021 akien <akien> 0.21.26-3.mga9.tainted
+ Revision: 1728206
- Rebuild for sndio 1.8.0 with fixed SONAME

* Sat Jan 16 2021 neoclust <neoclust> 0.21.26-2.mga8.tainted
+ Revision: 1672071
- Rebuild against new adplug

* Thu Dec 03 2020 luigiwalser <luigiwalser> 0.21.26-1.mga8.tainted
+ Revision: 1652181
- 0.21.26

* Mon Nov 30 2020 luigiwalser <luigiwalser> 0.21.25-2.mga8
+ Revision: 1650905
- rebuild for icu

* Mon Aug 24 2020 zezinho <zezinho> 0.21.25-1.mga8
+ Revision: 1618514
- new version 0.21.25

* Mon Aug 03 2020 daviddavid <daviddavid> 0.21.23-5.mga8
+ Revision: 1610687
- rebuild for new sndio 1.7.0

* Mon Jul 20 2020 wally <wally> 0.21.23-4.mga8
+ Revision: 1607391
- rebuild for zziplib 0.13.71
- build with libsidplayfp

* Wed Jul 01 2020 wally <wally> 0.21.23-3.mga8
+ Revision: 1601046
- rebuild for icu 67.1

* Sun May 24 2020 wally <wally> 0.21.23-2.mga8.tainted
+ Revision: 1587280
- rebuild for new libupnp 1.12.1

* Sun Apr 26 2020 zezinho <zezinho> 0.21.23-1.mga8.tainted
+ Revision: 1572283
- new version

* Mon Apr 06 2020 zezinho <zezinho> 0.21.22-1.mga8.tainted
+ Revision: 1565176
- new version

* Sat Apr 04 2020 wally <wally> 0.21.20-2.mga8.tainted
+ Revision: 1564483
- rebuild for new icu 66.1

* Tue Feb 25 2020 zezinho <zezinho> 0.21.20-1.mga8.tainted
+ Revision: 1550454
- new version

* Thu Feb 20 2020 umeabot <umeabot> 0.21.19-2.mga8.tainted
+ Revision: 1547341
- Mageia 8 Mass Rebuild

* Mon Feb 03 2020 zezinho <zezinho> 0.21.19-1.mga8
+ Revision: 1486681
- new version

* Thu Jan 09 2020 zezinho <zezinho> 0.21.18-1.mga8.tainted
+ Revision: 1477407
- new version

* Sun Oct 20 2019 zezinho <zezinho> 0.21.16-2.mga8
+ Revision: 1454715
- update README.urpmi instrucions for systemd

* Sat Oct 19 2019 zezinho <zezinho> 0.21.16-1.mga8.tainted
+ Revision: 1454591
- new version 0.21.16

* Sat Oct 05 2019 daviddavid <daviddavid> 0.21.15-2.mga8.tainted
+ Revision: 1449571
- rebuild for new icu 65.1

* Mon Sep 30 2019 zezinho <zezinho> 0.21.15-1.mga8
+ Revision: 1448220
- new version 0.21.15

* Mon Sep 16 2019 tv <tv> 0.21.14-2.mga8.tainted
+ Revision: 1442211
- rebuild for new libnfs

* Thu Aug 22 2019 daviddavid <daviddavid> 0.21.14-1.mga8.tainted
+ Revision: 1431262
- new version: 0.21.14
- add upstream patch to fix build
+ zezinho <zezinho>
- new version 0.21.12

* Fri Aug 02 2019 zezinho <zezinho> 0.21.11-1.mga8
+ Revision: 1426954
-disable mpcdec as build fails
- new version 0.21.11 - switch build to meson - add dependencies for adplug, chromaprint, gme, nfs, upnp, smb, soxr, wildmidi - disable shine and tremor

* Mon Jan 14 2019 luigiwalser <luigiwalser> 0.20.23-3.mga7.tainted
+ Revision: 1356815
- rebuild for fluidsynth

* Fri Jan 11 2019 daviddavid <daviddavid> 0.20.23-2.mga7.tainted
+ Revision: 1354743
- rebuild for new icu

* Wed Oct 31 2018 zezinho <zezinho> 0.20.23-1.mga7.tainted
+ Revision: 1326981
- new bugfix version 0.20.23

* Fri Oct 26 2018 zezinho <zezinho> 0.20.22-1.mga7.tainted
+ Revision: 1326010
- new version 0.20.22

* Fri Sep 21 2018 zezinho <zezinho> 0.20.21-1.mga7.tainted
+ Revision: 1294782
- new version 0.20.21

* Tue Aug 28 2018 daviddavid <daviddavid> 0.20.18-2.mga7.tainted
+ Revision: 1255146
- rebuild for new icu

* Mon Apr 23 2018 zezinho <zezinho> 0.20.18-1.mga7.tainted
+ Revision: 1221730
- new version 0.20.18

* Wed Feb 21 2018 kekepower <kekepower> 0.20.17-1.mga7
+ Revision: 1203840
- Update to version 0.20.17

* Sun Jan 14 2018 wally <wally> 0.20.13-2.mga7
+ Revision: 1193111
- disable libcdio-paranoia and iso9660 support for now as mpd isn't compatible with libcdio >= 1.1.0

* Sat Dec 30 2017 zezinho <zezinho> 0.20.13-1.mga7.tainted
+ Revision: 1187606
- new version

* Fri Dec 29 2017 wally <wally> 0.19.21-5.mga7
+ Revision: 1186994
- rebuild for new icu

* Tue May 02 2017 akien <akien> 0.19.21-4.mga6
+ Revision: 1098367
- Rebuild for ffmpeg 3.3

* Mon Mar 20 2017 akien <akien> 0.19.21-3.mga6.tainted
+ Revision: 1093678
- Rebuild for icu 58.2

* Wed Mar 08 2017 akien <akien> 0.19.21-2.mga6.tainted
+ Revision: 1089882
- Rebuild for ffmpeg 3.2.4

* Sun Jan 01 2017 luigiwalser <luigiwalser> 0.19.21-1.mga6.tainted
+ Revision: 1079367
- 0.19.21

* Sat Jun 25 2016 daviddavid <daviddavid> 0.19.15-7.mga6.tainted
+ Revision: 1037618
- submit to tainted/release

* Sat Jun 18 2016 luigiwalser <luigiwalser> 0.19.15-6.mga6
+ Revision: 1022616
- rebuild with fix libmad

* Wed Jun 08 2016 daviddavid <daviddavid> 0.19.15-5.mga6
+ Revision: 1020835
- submit to tainted/release

* Wed Jun 08 2016 tv <tv> 0.19.15-4.mga6
+ Revision: 1020780
- adjust BRs for latest systemd

* Fri May 20 2016 daviddavid <daviddavid> 0.19.15-3.mga6.tainted
+ Revision: 1017247
- rebuild for tainted/release

* Thu May 19 2016 pterjan <pterjan> 0.19.15-2.mga6
+ Revision: 1017029
- Rebuild for icu

* Sat May 14 2016 shlomif <shlomif> 0.19.15-1.mga6
+ Revision: 1015488
- New version + rebuild for ICU

* Sat Mar 12 2016 shlomif <shlomif> 0.19.13-1.mga6.tainted
+ Revision: 989647
- Add missing BR on boost-devel
- New version 0.19.13

* Mon Feb 15 2016 umeabot <umeabot> 0.18.8-6.mga6.tainted
+ Revision: 961528
- Mageia 6 Mass Rebuild

* Sat Aug 29 2015 cjw <cjw> 0.18.8-5.mga6
+ Revision: 870761
- fix build (with gcc 5)

* Thu Jul 16 2015 sander85 <sander85> 0.18.8-4.mga6.tainted
+ Revision: 854720
- Rebuild for new libcdio

* Fri Nov 14 2014 akien <akien> 0.18.8-3.mga5.tainted
+ Revision: 797079
- Rebuild for ffmpeg 2.4

* Thu Sep 04 2014 colin <colin> 0.18.8-2.mga5.tainted
+ Revision: 672049
- Rebuild for new systemd

* Thu Feb 20 2014 jquelin <jquelin> 0.18.8-1.mga5.tainted
+ Revision: 595047
- update to 0.18.8
+ luigiwalser <luigiwalser>
- rebuild for libcdio

* Sun Sep 01 2013 fwang <fwang> 0.17.4-3.mga4.tainted
+ Revision: 473954
- rebuild for new libcdio

* Mon Jul 15 2013 fwang <fwang> 0.17.4-2.mga4.tainted
+ Revision: 454468
- rebuild for new ffmpeg
- rebuild for new ffmpeg

* Wed Jun 26 2013 jquelin <jquelin> 0.17.4-1.mga4.tainted
+ Revision: 446842
- update to 0.17.4

* Sun Mar 24 2013 colin <colin> 0.17.3-5.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sun Jan 13 2013 luigiwalser <luigiwalser> 0.17.3-4.mga3.tainted
+ Revision: 362603
- add tmpfiles config for /run/mpd
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.17.3-2.mga3.tainted
+ Revision: 342346
- br sidplay2

* Tue Jan 08 2013 fwang <fwang> 0.17.3-1.mga3
+ Revision: 342340
- more br
- specify systemdunitdir
- add more br
- cleanup br
- new version 0.17.3

* Tue Jan 08 2013 fwang <fwang> 0.17.1-3.mga3.tainted
+ Revision: 341833
- rebuild for new ffmpeg

* Tue Nov 27 2012 jquelin <jquelin> 0.17.1-2.mga3
+ Revision: 322330
- rpm group change

* Fri Aug 17 2012 fedya <fedya> 0.17.1-1.mga3
+ Revision: 281780
- rpmlint warning fix
- version update 0.17.1

* Mon Jul 02 2012 jquelin <jquelin> 0.17-1.mga3.tainted
+ Revision: 266725
- update to 0.17

* Thu Jun 07 2012 jquelin <jquelin> 0.16.8-1.mga3.tainted
+ Revision: 256763
- update to 0.6.8

* Sat Apr 28 2012 tmb <tmb> 0.16.6-2.mga2.tainted
+ Revision: 233801
- Require rpm-helper >= 0.24.8-1 for systemd support

* Mon Jan 23 2012 fwang <fwang> 0.16.6-1.mga2
+ Revision: 200251
- new version 0.16.6

* Thu Jan 12 2012 fwang <fwang> 0.16.5-2.mga2.tainted
+ Revision: 195275
- rebuild for new audiofile

* Thu Nov 10 2011 jquelin <jquelin> 0.16.5-1.mga2
+ Revision: 166163
- update to 0.16.5
- make mpd.tainted play m4a files (mga#3290)

* Sat Sep 17 2011 jquelin <jquelin> 0.16.3-3.mga2
+ Revision: 144565
- fix bug#1630 - remove config/runtime options that are no longer supported

* Thu Jul 14 2011 kharec <kharec> 0.16.3-2.mga2
+ Revision: 124123
- fix README.urpmi (fix #1630)

* Mon Jul 11 2011 kharec <kharec> 0.16.3-1.mga2
+ Revision: 122136
- new version 0.16.3

* Sun May 29 2011 cjw <cjw> 0.16.2-2.mga1.tainted
+ Revision: 100690
- add support for tainted builds

* Fri Apr 15 2011 shikamaru <shikamaru> 0.16.2-1.mga1
+ Revision: 85901
- New version 0.16.2
- retab (mix use of space and tabs)

* Tue Mar 01 2011 jquelin <jquelin> 0.16.1-1.mga1
+ Revision: 62012
- update to 0.16.1

* Sun Jan 09 2011 jquelin <jquelin> 0.15.13-1.mga1
+ Revision: 1714
- imported package mpd

